.. figure:: https://raw.github.com/wq/wq/master/images/512/wq.png
   :align: center
   :alt: wq

A modular framework for mobile & desktop geographic data collection
applications.

Includes the following submodules:

.. figure:: https://raw.github.com/wq/wq/master/images/80/wq.app.png     
   :alt: wq.app

   ..

   A JavaScript+Python library for building robust offline-capable HTML5 data entry apps.

.. figure:: https://raw.github.com/wq/wq/master/images/80/wq.db.png
   :alt: wq.db

   ..

   Django database models and REST framework to support design patterns common to data collection systems.

.. figure:: https://raw.github.com/wq/wq/master/images/80/wq.io.png
   :alt: wq.io

   ..

   Python interoperability library for consuming and generating data resources in various formats.
